#!/usr/bin/env python
import sys, math, serial, os


def readLine(ser):
	str=""
	while 1:
		ch=ser.read()
		if(ch == '\r' or ch == '\n'):
			break
		str += ch
	return str


def findChar(str,look):
	i = 0
	while i < len(str) - 1:
		if(str[i] == look):
			return 1
		i += 1
	return 0
	
			
def setSample():
#setup serial port
	i = 1
	port = serial.Serial("/dev/ttyUSB0", baudrate=115200, timeout=3.0)
	port.nonblocking()
	port.write('x\r\n')
	r = readLine(port)
	while i == 1:
		while findChar(r,';') == 1:
			r = readLine(port)
		r = readLine(port)
		if findChar(r,';') != 1:
			break
		r = readLine(port)

	os.system('echo ++  >> /dev/ttyUSB0')
	r = readLine(port)
	r = readLine(port)
	port.flush()
	port.close()
	
	
#end  set SSP sample rate	
	
def clean(string):
	sep = '='
	string = string.strip('\r\n')
	string = string.split(sep)
	string = string[1]
	return string

def readConfig():
	try:
		rStream = open('/home/pi/config1.txt','r')
		lastState = clean(rStream.readline())
		calBad = clean(rStream.readline())
		calx = clean(rStream.readline())
		caly = clean(rStream.readline())
		calz = clean(rStream.readline())
		threshold = clean(rStream.readline())
		num = clean(rStream.readline())
		rStream.close()
	except IOError:
		lastState = 0
		calBad = 1
		calx = 0
		caly = 0
		calz = 0
		threshold = 1000
		num = '5551112222@junk'
	return lastState, calBad, calx, caly, calz, threshold, num
# end readConfig file


def writeConfig():
	wStream = open('/home/pi/config1.txt','w')
	wStream.write('laststate=' + str(lastState) + '\r\n')
	wStream.write('calBad=' + str(calBad) + '\r\n')
	wStream.write('calx=' + str(calx) + '\r\n')
	wStream.write('caly=' + str(caly) + '\r\n')
	wStream.write('calz=' + str(calz) + '\r\n')
	wStream.write('threshold=' + str(threshold) + '\r\n')
	wStream.write('num=' + str(num) + '\r\n')
	wStream.close()
	return 1
#end writeConfig


def calibration():
	port = serial.Serial("/dev/ttyUSB0", baudrate=115200, timeout=3.0)
	calx = 0
	caly = 0
	calz = 0
	maxC = 200
	count = maxC
	token = ','
	while count != 0:
		rcv = port.readline()
		rcv = rcv.strip('\r\n')
		loc = rcv.split(token)
		#if data is invalid, get another sample
		if(len(loc) < 4):
			count += 1
		elif(findChar(rcv,';') == 1 ):
				count += 1
		else:
			x = int(loc[1])
			y = int(loc[2])
			z = int(loc[3])
			if count:
				calx += x
				caly += y
				calz += z
		count -= 1
	calx /= maxC
	caly /= maxC
	calz /= maxC
	port.close()
	return calx, caly, calz
#end Calibration


# start main program
#setup serial port
port = serial.Serial("/dev/ttyUSB0", baudrate=115200, timeout=3.0)
setSample()

#set config values
cfg = readConfig()
lastState = int(cfg[0])
calBad = int(cfg[1])
threshold = int(cfg[5])
num = cfg[6]
mailCmd ='echo Clothes are dry | mail -s DryerStatus ' + num

if calBad == 1:
	cal = calibration()
	calx = int(cal[0])
	caly = int(cal[1])
	calz = int(cal[2])
	calBad = 0
else:
	calx = int(cfg[2])
	caly = int(cfg[3])
	calz = int(cfg[4])
# end config value setup	
	
setSample()

maxCount = 100
token = ',' 		# token used to split serial data
magAvg = 0			# magnitude average value	
i = 0				# number of magnitudes to average
magA = 0			# sum of the magnitudes
magMax = 0			# Maximum Magnitude
magMin = 1000000	# Minimum Magnitude
while 1:
	count = maxCount
	mag = 0

	while count != 0:
			rcv = port.readline()
			rcv = rcv.strip('\r\n')
			loc = rcv.split(token)
			if(len(loc) < 4):
				count += 1
			elif(findChar(rcv,';') == 1 ):
				count += 1
			else:
				try:
					x = int(loc[1]) - calx
					y = int(loc[2])	- caly
					z = int(loc[3]) - calz
				except ValueError:
					count +=1
	
				mag += math.sqrt(x*x+y*y+z*z)

				count -= 1

		
	mag /= maxCount
	i += 1
	if(magMax < mag):
		magMax = mag
	if(magMin > mag):
		magMin = mag
	magA = (magA + mag) 
	magAvg = magA / i
	print 'Mag is %2f Average is %2f  Max is %2f  Min is %2f' % (mag, magAvg, magMax, magMin)
port.close()

